@@ -40,19 +40,34 @@ function setShinyValue(instance) {
 }
 
 function setShinyValueSelectedNodes(instance, leavesOnly) {
-  var nodes = getNodes(instance.get_selected(true));
+  var selectedNodes = instance.get_selected(true);
+  var nodes = getNodes(selectedNodes);
   var leaves = [];
+  var pathNodes = [];
+  var leavePathNodes = [];
   for (var i = 0; i < nodes.length; i++) {
-    var nchildren = nodes[i].children.length;
+    var node = nodes[i];
+    var path = instance.get_path(selectedNodes[i], "/");
+    var pathNode = {
+      path: path,
+      data: node.data
+    };
+    pathNodes.push(pathNode);
+    var nchildren = node.children.length;
     delete nodes[i].children;
     if (leavesOnly && nchildren === 0) {
       leaves.push(nodes[i]);
+      leavePathNodes.push(pathNode);
     }
   }
   Shiny.setInputValue(
     instance.element.attr("id") + "_selected:jsTreeR.list",
     leavesOnly ? leaves : nodes
   );
+  Shiny.setInputValue(
+    instance.element.attr("id") + "_selected_paths:jsTreeR.list",
+    leavesOnly ? leavePathNodes : pathNodes
+  );
 }
 
 var inShiny = HTMLWidgets.shinyMode;
